@@ -16,9 +16,6 @@
  * Boston, MA 021110-1307, USA.
  */
 
-#define _XOPEN_SOURCE 500
-#define _GNU_SOURCE
-
 #include "kerncompat.h"
 
 #include <sys/ioctl.h>
@@ -35,6 +32,8 @@
 #include <uuid/uuid.h>
 #include <ctype.h>
 #include <sys/xattr.h>
+#include <limits.h>
+#include <linux/limits.h>
 #include <blkid/blkid.h>
 #include <ftw.h>
 #include "ctree.h"
@@ -46,7 +45,8 @@
 
 static u64 index_cnt = 2;
 
-#define DEFAULT_MKFS_FEATURES	(BTRFS_FEATURE_INCOMPAT_EXTENDED_IREF)
+#define DEFAULT_MKFS_FEATURES	(BTRFS_FEATURE_INCOMPAT_EXTENDED_IREF \
+		| BTRFS_FEATURE_INCOMPAT_SKINNY_METADATA)
 
 #define DEFAULT_MKFS_LEAF_SIZE 16384
 
@@ -337,25 +337,6 @@ static char *parse_label(char *input)
 	return strdup(input);
 }
 
-static struct option long_options[] = {
-	{ "alloc-start", 1, NULL, 'A'},
-	{ "byte-count", 1, NULL, 'b' },
-	{ "force", 0, NULL, 'f' },
-	{ "leafsize", 1, NULL, 'l' },
-	{ "label", 1, NULL, 'L'},
-	{ "metadata", 1, NULL, 'm' },
-	{ "mixed", 0, NULL, 'M' },
-	{ "nodesize", 1, NULL, 'n' },
-	{ "sectorsize", 1, NULL, 's' },
-	{ "data", 1, NULL, 'd' },
-	{ "version", 0, NULL, 'V' },
-	{ "rootdir", 1, NULL, 'r' },
-	{ "nodiscard", 0, NULL, 'K' },
-	{ "features", 1, NULL, 'O' },
-	{ "uuid", required_argument, NULL, 'U' },
-	{ NULL, 0, NULL, 0}
-};
-
 static int add_directory_items(struct btrfs_trans_handle *trans,
 			       struct btrfs_root *root, u64 objectid,
 			       ino_t parent_inum, const char *name,
@@ -1255,7 +1236,6 @@ int main(int ac, char **av)
 	u32 nodesize = leafsize;
 	u32 stripesize = 4096;
 	int zero_end = 1;
-	int option_index = 0;
 	int fd;
 	int ret;
 	int i;
@@ -1280,6 +1260,26 @@ int main(int ac, char **av)
 
 	while(1) {
 		int c;
+		int option_index = 0;
+		static const struct option long_options[] = {
+			{ "alloc-start", 1, NULL, 'A'},
+			{ "byte-count", 1, NULL, 'b' },
+			{ "force", 0, NULL, 'f' },
+			{ "leafsize", 1, NULL, 'l' },
+			{ "label", 1, NULL, 'L'},
+			{ "metadata", 1, NULL, 'm' },
+			{ "mixed", 0, NULL, 'M' },
+			{ "nodesize", 1, NULL, 'n' },
+			{ "sectorsize", 1, NULL, 's' },
+			{ "data", 1, NULL, 'd' },
+			{ "version", 0, NULL, 'V' },
+			{ "rootdir", 1, NULL, 'r' },
+			{ "nodiscard", 0, NULL, 'K' },
+			{ "features", 1, NULL, 'O' },
+			{ "uuid", required_argument, NULL, 'U' },
+			{ NULL, 0, NULL, 0}
+		};
+
 		c = getopt_long(ac, av, "A:b:fl:n:s:m:d:L:O:r:U:VMK",
 				long_options, &option_index);
 		if (c < 0)
@@ -1588,11 +1588,11 @@ int main(int ac, char **av)
 
 	trans = btrfs_start_transaction(root, 1);
 
+	btrfs_register_one_device(file);
+
 	if (dev_cnt == 0)
 		goto raid_groups;
 
-	btrfs_register_one_device(file);
-
 	while (dev_cnt-- > 0) {
 		int old_mixed = mixed;
 
